/**************************************************************************
 *  Author: The Kopio offline project.                                    *
 *  Contributors are mentioned in the code where appropriate.             *
 **************************************************************************/

///////////////////////////////////////////////////////////////////////////
// A manager class to provide a link between MC data and consumer classes
// (reconstruction classes, event display classes and etc). It is supposed
// that this class will be one of the Kopio offline package. When loading
// this class separately, you need to do the following items:
//
// 1) Convert a GEANT generated ntuple file into a root file (by h2root).
// 2) In ROOT session, open the newly created root file and create two
//    skeleton classes calling them KopioMCntuple1 and KopioMCntuple5:
//    root> h1->MakeClass("KopioMCntuple1");
//    root> h5->MakeClass("KopioMCntuple5");
// 3) Rename an extension of the above created classes: ClassName.C ->
//    ClassName.cxx and make a shared library for each of them.
//
// There are basically two ways to load this class:
//
// 1) gSystem->Load("libKopioMCntuple1.so"); or |root> .L libKopioMCntuple1.so
//    gSystem->Load("libKopioMCntuple5.so"); or |root> .L libKopioMCntuple5.so
//    gSystem->Load("libKopioMCLoader.so");  or |root> .L libKopioMCLoader.so
//
// 2) .O 0 // to turn off CINT optimizations
//    .L KopioMCntuple1.cxx
//    .L KopioMCntuple5.cxx
//    .L KopioMCLoader.cxx
//
// By default if you create an object by invoking
//
// KopioMCLoader ld;
// 
// the constructor of this class will use a file used to generate the skeleton
// classes KopioMCntuple1 and KopioMCntuple5. If you want to work with another
// root file, you need to do the following
//
// TFile f("myfile.root");
// TTree *t1 = (TTree *) f.Get("h1");
// TTree *t5 = (TTree *) f.Get("h5");
// KopioMCLoader ld(t1,t5);
//
// --- Author: Alexander Artamonov (IHEP, Russia) 10-Jun-2004
///////////////////////////////////////////////////////////////////////////

// --- Srandard library header files ---

#include <iostream.h>

// --- ROOT system header files ---

// --- KopioROOT header files ---

#include "KopioMCLoader.h"
 
ClassImp(KopioMCLoader) // Class implementation to enable ROOT I/O
///////////////////////////////////////////////////////////////////////////
KopioMCLoader::KopioMCLoader(TTree *tree1, TTree *tree5) : KopioMCntuple1(tree1), KopioMCntuple5(tree5)
{
// The default constructor.
}
///////////////////////////////////////////////////////////////////////////
KopioMCLoader::KopioMCLoader(const KopioMCLoader &loader) : KopioMCntuple1(loader), KopioMCntuple5(loader)
{
// The copy constructor.
}
///////////////////////////////////////////////////////////////////////////
KopioMCLoader::~KopioMCLoader()
{
// The destructor.
  cout << "<KopioMCLoader::~KopioMCLoader>: Test output" << endl;
}
///////////////////////////////////////////////////////////////////////////
